]> git.sesse.net Git - cubemap/blobdiff - stream.h
Move Server:add_data() into Stream, where it more logically belongs.
[cubemap] / stream.h
index ea13f40bd6258dffe1e9a22619d889688e97fd9e..a57c6d88e7ff0955a68e0d02fceeb0910bd7491f 100644 (file)
--- a/stream.h
+++ b/stream.h
@@ -60,11 +60,14 @@ struct Stream {
        // in the list of clients to wake up when we do.
        void put_client_to_sleep(Client *client);
 
-       // We have more data, so mark all clients that are sleeping as ready to go.
-       void wake_up_all_clients();
+       // Add more input data to the stream, and wake up all clients that are sleeping.
+       void add_data(const char *data, ssize_t bytes);
 
 private:
        Stream(const Stream& other);
+
+       // We have more data, so mark all clients that are sleeping as ready to go.
+       void wake_up_all_clients();
 };
 
 #endif  // !defined(_STREAM_H)